#
# spec file for package ghc-hexpat
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name hexpat
Name:           ghc-%{pkg_name}
Version:        0.20.13
Release:        8.9
Summary:        XML parser/formatter based on expat
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-List-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  libexpat-devel

%description
This package provides a general purpose Haskell XML library using Expat to do
its parsing (<http://expat.sourceforge.net/> - a fast stream-oriented XML
parser written in C). It is extensible to any string type, with 'String',
'ByteString' and 'Text' provided out of the box.

Basic usage: Parsing a tree (/Tree/), formatting a tree (/Format/).
Other features: Helpers for processing XML trees (/Proc/), trees annotated with
XML source location (/Annotated/), extended XML trees with comments, processing
instructions, etc (/Extended/), XML cursors (/Cursor/), SAX-style parse
(/SAX/), and access to the low-level interface in case speed is paramount
(/Internal.IO/).

The design goals are speed, speed, speed, interface simplicity and modularity.

For introduction and examples, see the /Text.XML.Expat.Tree/ module.
For benchmarks, <http://haskell.org/haskellwiki/Hexpat/>

If you want to do interactive I/O, an obvious option is to use lazy parsing
with one of the lazy I/O functions such as hGetContents. However, this can be
problematic in some applications because it doesn't handle I/O errors properly
and can give no guarantee of timely resource cleanup. Because of the
generalized list, Hexpat is designed to allow for chunked I/O, but as of this
writing I haven't done a nice integration with enumerator and friends.

/IO/ is filed under /Internal/ because it's low-level and most users won't want
it. The other /Internal/ modules are re-exported by /Annotated/, /Tree/ and
/Extended/, so you won't need to import them directly.

If you have trouble building on Windows, you can try the bundle flag.
This will make it build from the source of libexpat bundled inside the hexpat
package: cabal install -f bundle hexpat

Credits to Iavor Diatchki and the 'xml' (XML.Light) package for /Proc/ and
/Cursor/. Thanks to the many contributors.

ChangeLog: 0.15 changes intended to fix a (rare) "error: a C finalizer called
back into Haskell." that seemed only to happen only on ghc6.12.X; 0.15.1 Fix
broken Annotated parse; 0.16 switch from mtl to transformers; 0.17 fix
mapNodeContainer & rename some things.; 0.18 rename defaultEncoding to
overrideEncoding. 0.18.3 formatG and indent were demanding list items more than
once (inefficient in chunked processing); 0.19 add Extended.hs; 0.19.1 fix a
memory leak introduced in 0.19, delegate parsing to bound thread if unbound
(see note above); 0.19.2 include expat source code so 'cabal install' just
works on Linux, Mac and Windows (thanks Jacob Stanley); 0.19.3 fix
misconfiguration of expat which broke entity parsing; 0.19.4 bump version
constraint for text; 0.19.5 bump text to < 0.12 and fix text-0.10.0.1 breakage;
0.19.6 dependency breakage with List; 0.19.7 ghc-7.2.1 compatibility; 0.19.8
fix space leak on lazy parse under ghc-7.2.1; 0.19.9 fix formatting of >
character + improve performance; 0.19.10 ghc-7.4.x compatibility; 0.20.1 fix an
unfortunate crash when used in parallel processing and greatly improve
performance; 0.20.2 make parseSaxG lazier; 0.20.3 minor build issues; 0.20.4
remove dependency on extensible-exceptions; 0.20.5 bump text upper bound;
0.20.6 bump text again to include 1.1.x.x; 0.20.7 bump text again for 1.2.x.x;
0.20.8 bump utf8-string dep; 0.20.9 bump deepseq dep/ghc-7.10 compatibility.;
0.20.10 increase dependency upper bounds; 0.20.11 update to libexpat-2.2.1
which includes several security fixes; 0.20.12 use the system libexpat by
default, but provide a bundle flag to allow a bundled copy of expat to be used,
which might make life easier on Windows: cabal install -f bundle hexpat;
0.20.13 Fix some mistakes made in 0.20.12 cabal file.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires:       libexpat-devel
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jun 25 2017 psimons@suse.com
- Update to version 0.20.13.
* Tue Mar 14 2017 psimons@suse.com
- Update to version 0.20.10 with cabal2obs.
